[Mesa-dev] [PATCH 2/7] glsl: Forbid calling the constructor of any opaque type.

Francisco Jerez currojerez at riseup.net
Sat Jan 31 12:54:24 PST 2015


The spec doesn't define any opaque type constructors.
---
 src/glsl/ast_function.cpp | 6 +++---
 1 file changed, 3 insertions(+), 3 deletions(-)

diff --git a/src/glsl/ast_function.cpp b/src/glsl/ast_function.cpp
index cbff9d8..151b082 100644
--- a/src/glsl/ast_function.cpp
+++ b/src/glsl/ast_function.cpp
@@ -1524,10 +1524,10 @@ ast_function_expression::hir(exec_list *instructions,
       }
 
 
       /* Constructors for samplers are illegal.
        */
-      if (constructor_type->is_sampler()) {
-	 _mesa_glsl_error(& loc, state, "cannot construct sampler type `%s'",
+      if (constructor_type->contains_opaque()) {
+	 _mesa_glsl_error(& loc, state, "cannot construct opaque type `%s'",
 			  constructor_type->name);
 	 return ir_rvalue::error_value(ctx);
       }
@@ -1524,10 +1524,10 @@ ast_function_expression::hir(exec_list *instructions,
 
 
-      /* Constructors for samplers are illegal.
+      /* Constructors for opaque types are illegal.
        */
-- 
2.1.3



More information about the mesa-dev mailing list